==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ms/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Bidang Tersuai',
    'field'		                => 'Padang',
    'about_fieldsets_title'		=> 'Mengenai Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets membolehkan anda membuat kumpulan bidang tersuai yang sering digunakan semula digunakan untuk jenis model aset tertentu.',
    'custom_format'             => 'Format tersuai ...',
    'encrypt_field'      	        => 'Sulitkan nilai medan ini dalam pangkalan data',
    'encrypt_field_help'      => 'AMARAN: Menyulitkan medan menjadikannya tidak dapat ditemui.',
    'encrypted'      	        => 'Disulitkan',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Qty Fields',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nama Fieldset',
    'field_name'              => 'Nama Field',
    'field_values'            => 'Nilai Field',
    'field_values_help'       => 'Tambah pilihan pilihan, satu setiap baris. Barisan kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Borang Elemen',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Tersuai',
    'field_custom_format_help'     => 'Medan ini membolehkan anda menggunakan ungkapan regex untuk pengesahan. Ia harus bermula dengan "regex:" - sebagai contoh, untuk mengesahkan bahawa nilai medan khusus mengandungi IMEI yang sah (15 angka numerik), anda akan menggunakan <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Diperlukan',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan Oleh Model',
    'order'   		            => 'Perintah',
    'create_fieldset'         => 'Fieldset baru',
    'create_field'            => 'Padang Tersuai Baru',
    'value_encrypted'      	        => 'Nilai medan ini disulitkan dalam pangkalan data. Hanya pengguna admin sahaja yang dapat melihat nilai yang disahkrit',
    'show_in_email'     => 'Sertakan nilai medan ini dalam e-mel semak keluar yang dihantar kepada pengguna? Medan yang disulitkan tidak boleh dimasukkan ke dalam e-mel.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ms/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Bidang Tersuai',
    'manage'                    => 'Manage',
    'field'		                => 'Padang',
    'about_fieldsets_title'		=> 'Mengenai Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Sulitkan nilai medan ini dalam pangkalan data',
    'encrypt_field_help'      => 'AMARAN: Menyulitkan medan menjadikannya tidak dapat ditemui.',
    'encrypted'      	        => 'Disulitkan',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Qty Fields',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nama Fieldset',
    'field_name'              => 'Nama Field',
    'field_values'            => 'Nilai Field',
    'field_values_help'       => 'Tambah pilihan pilihan, satu setiap baris. Barisan kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Borang Elemen',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Tersuai',
    'field_custom_format_help'     => 'Medan ini membolehkan anda menggunakan ungkapan regex untuk pengesahan. Ia harus bermula dengan "regex:" - sebagai contoh, untuk mengesahkan bahawa nilai medan khusus mengandungi IMEI yang sah (15 angka numerik), anda akan menggunakan <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Diperlukan',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan Oleh Model',
    'order'   		            => 'Perintah',
    'create_fieldset'         => 'Fieldset baru',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Padang Tersuai Baru',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Nilai medan ini disulitkan dalam pangkalan data. Hanya pengguna admin sahaja yang dapat melihat nilai yang disahkrit',
    'show_in_email'     => 'Sertakan nilai medan ini dalam e-mel semak keluar yang dihantar kepada pengguna? Medan yang disulitkan tidak boleh dimasukkan ke dalam e-mel.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
